/*
 * Copyright (c) 1994 Cygnus Support.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * and/or other materials related to such
 * distribution and use acknowledge that the software was developed
 * at Cygnus Support, Inc.  Cygnus Support, Inc. may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "test.h"
 one_line_type asinh_vec[] = {
{64, 0,123,__LINE__, 0xbff0416d, 0x0b8ea990, 0xbff33333, 0x33333333},	/* -1.01597=f(-1.2)*/
{64, 0,123,__LINE__, 0xbff02723, 0xaed3e28c, 0xbff30a3d, 0x70a3d70a},	/* -1.00956=f(-1.19)*/
{64, 0,123,__LINE__, 0xbff00cb9, 0x18514e77, 0xbff2e147, 0xae147ae1},	/* -1.00311=f(-1.18)*/
{64, 0,123,__LINE__, 0xbfefe45a, 0x23bb819a, 0xbff2b851, 0xeb851eb8},	/* -0.996625=f(-1.17)*/
{64, 0,123,__LINE__, 0xbfefaefe, 0xcad19f15, 0xbff28f5c, 0x28f5c28f},	/* -0.990112=f(-1.16)*/
{63, 0,123,__LINE__, 0xbfef795f, 0xba0209b9, 0xbff26666, 0x66666666},	/* -0.983566=f(-1.15)*/
{64, 0,123,__LINE__, 0xbfef437c, 0x85b4a6d2, 0xbff23d70, 0xa3d70a3d},	/* -0.976988=f(-1.14)*/
{64, 0,123,__LINE__, 0xbfef0d54, 0xc2a99e3a, 0xbff2147a, 0xe147ae14},	/* -0.970377=f(-1.13)*/
{63, 0,123,__LINE__, 0xbfeed6e8, 0x060758e2, 0xbff1eb85, 0x1eb851eb},	/* -0.963734=f(-1.12)*/
{64, 0,123,__LINE__, 0xbfeea035, 0xe5691026, 0xbff1c28f, 0x5c28f5c2},	/* -0.957057=f(-1.11)*/
{64, 0,123,__LINE__, 0xbfee693d, 0xf6edf1e5, 0xbff19999, 0x99999999},	/* -0.950347=f(-1.1)*/
{64, 0,123,__LINE__, 0xbfee31ff, 0xd148dd59, 0xbff170a3, 0xd70a3d70},	/* -0.943603=f(-1.09)*/
{64, 0,123,__LINE__, 0xbfedfa7b, 0x0bd0bc8a, 0xbff147ae, 0x147ae147},	/* -0.936826=f(-1.08)*/
{64, 0,123,__LINE__, 0xbfedc2af, 0x3e917e7a, 0xbff11eb8, 0x51eb851e},	/* -0.930015=f(-1.07)*/
{64, 0,123,__LINE__, 0xbfed8a9c, 0x025db5de, 0xbff0f5c2, 0x8f5c28f5},	/* -0.92317=f(-1.06)*/
{64, 0,123,__LINE__, 0xbfed5240, 0xf0e0e077, 0xbff0cccc, 0xcccccccc},	/* -0.916291=f(-1.05)*/
{64, 0,123,__LINE__, 0xbfed199d, 0xa4b25ad8, 0xbff0a3d7, 0x0a3d70a3},	/* -0.909377=f(-1.04)*/
{64, 0,123,__LINE__, 0xbfece0b1, 0xb969049f, 0xbff07ae1, 0x47ae147a},	/* -0.902428=f(-1.03)*/
{63, 0,123,__LINE__, 0xbfeca77c, 0xcbaf98d7, 0xbff051eb, 0x851eb851},	/* -0.895445=f(-1.02)*/
{64, 0,123,__LINE__, 0xbfec6dfe, 0x7959be65, 0xbff028f5, 0xc28f5c28},	/* -0.888427=f(-1.01)*/
{64, 0,123,__LINE__, 0xbfec3436, 0x6179d425, 0xbfefffff, 0xfffffffe},	/* -0.881374=f(-1)*/
{63, 0,123,__LINE__, 0xbfebfa24, 0x24777c62, 0xbfefae14, 0x7ae147ac},	/* -0.874285=f(-0.99)*/
{64, 0,123,__LINE__, 0xbfebbfc7, 0x6426eb13, 0xbfef5c28, 0xf5c28f5a},	/* -0.867161=f(-0.98)*/
{63, 0,123,__LINE__, 0xbfeb851f, 0xc3e0fa67, 0xbfef0a3d, 0x70a3d708},	/* -0.86=f(-0.97)*/
{64, 0,123,__LINE__, 0xbfeb4a2c, 0xe89c08b3, 0xbfeeb851, 0xeb851eb6},	/* -0.852805=f(-0.96)*/
{63, 0,123,__LINE__, 0xbfeb0eee, 0x7905a2f9, 0xbfee6666, 0x66666664},	/* -0.845573=f(-0.95)*/
{64, 0,123,__LINE__, 0xbfead364, 0x1d9cfee2, 0xbfee147a, 0xe147ae12},	/* -0.838305=f(-0.94)*/
{64, 0,123,__LINE__, 0xbfea978d, 0x80ce46dc, 0xbfedc28f, 0x5c28f5c0},	/* -0.831=f(-0.93)*/
{63, 0,123,__LINE__, 0xbfea5b6a, 0x4f0ebad9, 0xbfed70a3, 0xd70a3d6e},	/* -0.823659=f(-0.92)*/
{64, 0,123,__LINE__, 0xbfea1efa, 0x36f9a7f3, 0xbfed1eb8, 0x51eb851c},	/* -0.816281=f(-0.91)*/
{64, 0,123,__LINE__, 0xbfe9e23c, 0xe96e38d2, 0xbfeccccc, 0xccccccca},	/* -0.808867=f(-0.9)*/
{64, 0,123,__LINE__, 0xbfe9a532, 0x19ae208e, 0xbfec7ae1, 0x47ae1478},	/* -0.801415=f(-0.89)*/
{63, 0,123,__LINE__, 0xbfe967d9, 0x7d7d215a, 0xbfec28f5, 0xc28f5c26},	/* -0.793927=f(-0.88)*/
{64, 0,123,__LINE__, 0xbfe92a32, 0xcd416fe8, 0xbfebd70a, 0x3d70a3d4},	/* -0.786401=f(-0.87)*/
{63, 0,123,__LINE__, 0xbfe8ec3d, 0xc424f41c, 0xbfeb851e, 0xb851eb82},	/* -0.778838=f(-0.86)*/
{64, 0,123,__LINE__, 0xbfe8adfa, 0x2037673e, 0xbfeb3333, 0x33333330},	/* -0.771237=f(-0.85)*/
{64, 0,123,__LINE__, 0xbfe86f67, 0xa2914f46, 0xbfeae147, 0xae147ade},	/* -0.763599=f(-0.84)*/
{64, 0,123,__LINE__, 0xbfe83086, 0x0f77d693, 0xbfea8f5c, 0x28f5c28c},	/* -0.755923=f(-0.83)*/
{64, 0,123,__LINE__, 0xbfe7f155, 0x2e817eac, 0xbfea3d70, 0xa3d70a3a},	/* -0.74821=f(-0.82)*/
{63, 0,123,__LINE__, 0xbfe7b1d4, 0xcabbac29, 0xbfe9eb85, 0x1eb851e8},	/* -0.740458=f(-0.81)*/
{63, 0,123,__LINE__, 0xbfe77204, 0xb2d1095c, 0xbfe99999, 0x99999996},	/* -0.732668=f(-0.8)*/
{63, 0,123,__LINE__, 0xbfe731e4, 0xb930bc88, 0xbfe947ae, 0x147ae144},	/* -0.724841=f(-0.79)*/
{64, 0,123,__LINE__, 0xbfe6f174, 0xb4366df1, 0xbfe8f5c2, 0x8f5c28f2},	/* -0.716975=f(-0.78)*/
{64, 0,123,__LINE__, 0xbfe6b0b4, 0x7e531942, 0xbfe8a3d7, 0x0a3d70a0},	/* -0.70907=f(-0.77)*/
{63, 0,123,__LINE__, 0xbfe66fa3, 0xf636a4fa, 0xbfe851eb, 0x851eb84e},	/* -0.701128=f(-0.76)*/
{64, 0,123,__LINE__, 0xbfe62e42, 0xfefa39ec, 0xbfe7ffff, 0xfffffffc},	/* -0.693147=f(-0.75)*/
{64, 0,123,__LINE__, 0xbfe5ec91, 0x804b53dc, 0xbfe7ae14, 0x7ae147aa},	/* -0.685128=f(-0.74)*/
{64, 0,123,__LINE__, 0xbfe5aa8f, 0x66978381, 0xbfe75c28, 0xf5c28f58},	/* -0.67707=f(-0.73)*/
{64, 0,123,__LINE__, 0xbfe5683c, 0xa338d93d, 0xbfe70a3d, 0x70a3d706},	/* -0.668974=f(-0.72)*/
{64, 0,123,__LINE__, 0xbfe52599, 0x2ca2eee0, 0xbfe6b851, 0xeb851eb4},	/* -0.66084=f(-0.71)*/
{64, 0,123,__LINE__, 0xbfe4e2a4, 0xfe9085da, 0xbfe66666, 0x66666662},	/* -0.652667=f(-0.7)*/
{64, 0,123,__LINE__, 0xbfe49f60, 0x1a31ae2f, 0xbfe6147a, 0xe147ae10},	/* -0.644455=f(-0.69)*/
{64, 0,123,__LINE__, 0xbfe45bca, 0x865a6965, 0xbfe5c28f, 0x5c28f5be},	/* -0.636205=f(-0.68)*/
{64, 0,123,__LINE__, 0xbfe417e4, 0x4fb1bb94, 0xbfe570a3, 0xd70a3d6c},	/* -0.627916=f(-0.67)*/
{64, 0,123,__LINE__, 0xbfe3d3ad, 0x88e11b93, 0xbfe51eb8, 0x51eb851a},	/* -0.61959=f(-0.66)*/
{64, 0,123,__LINE__, 0xbfe38f26, 0x4ac4320f, 0xbfe4cccc, 0xccccccc8},	/* -0.611224=f(-0.65)*/
{64, 0,123,__LINE__, 0xbfe34a4e, 0xb498d62a, 0xbfe47ae1, 0x47ae1476},	/* -0.602821=f(-0.64)*/
{63, 0,123,__LINE__, 0xbfe30526, 0xec2f34f4, 0xbfe428f5, 0xc28f5c24},	/* -0.594379=f(-0.63)*/
{64, 0,123,__LINE__, 0xbfe2bfaf, 0x1e1a0fec, 0xbfe3d70a, 0x3d70a3d2},	/* -0.585899=f(-0.62)*/
{64, 0,123,__LINE__, 0xbfe279e7, 0x7ddefd46, 0xbfe3851e, 0xb851eb80},	/* -0.577381=f(-0.61)*/
{64, 0,123,__LINE__, 0xbfe233d0, 0x46269390, 0xbfe33333, 0x3333332e},	/* -0.568825=f(-0.6)*/
{64, 0,123,__LINE__, 0xbfe1ed69, 0xb8ec68f2, 0xbfe2e147, 0xae147adc},	/* -0.560231=f(-0.59)*/
{64, 0,123,__LINE__, 0xbfe1a6b4, 0x1faeccee, 0xbfe28f5c, 0x28f5c28a},	/* -0.5516=f(-0.58)*/
{63, 0,123,__LINE__, 0xbfe15faf, 0xcb9e2243, 0xbfe23d70, 0xa3d70a38},	/* -0.542931=f(-0.57)*/
{64, 0,123,__LINE__, 0xbfe1185d, 0x15cbbd57, 0xbfe1eb85, 0x1eb851e6},	/* -0.534224=f(-0.56)*/
{63, 0,123,__LINE__, 0xbfe0d0bc, 0x5f582a20, 0xbfe19999, 0x99999994},	/* -0.52548=f(-0.55)*/
{64, 0,123,__LINE__, 0xbfe088ce, 0x11a0bb69, 0xbfe147ae, 0x147ae142},	/* -0.5167=f(-0.54)*/
{64, 0,123,__LINE__, 0xbfe04092, 0x9e6c43fb, 0xbfe0f5c2, 0x8f5c28f0},	/* -0.507882=f(-0.53)*/
{64, 0,123,__LINE__, 0xbfdff015, 0x002db22e, 0xbfe0a3d7, 0x0a3d709e},	/* -0.499028=f(-0.52)*/
{63, 0,123,__LINE__, 0xbfdf5e6c, 0x7378f8ed, 0xbfe051eb, 0x851eb84c},	/* -0.490138=f(-0.51)*/
{64, 0,123,__LINE__, 0xbfdecc2c, 0xaec515ff, 0xbfdfffff, 0xfffffff4},	/* -0.481212=f(-0.5)*/
{63, 0,123,__LINE__, 0xbfde3956, 0xdc3f98b1, 0xbfdf5c28, 0xf5c28f50},	/* -0.47225=f(-0.49)*/
{64, 0,123,__LINE__, 0xbfdda5ec, 0x3885fd17, 0xbfdeb851, 0xeb851eac},	/* -0.463252=f(-0.48)*/
{63, 0,123,__LINE__, 0xbfdd11ee, 0x12ef7037, 0xbfde147a, 0xe147ae08},	/* -0.454219=f(-0.47)*/
{64, 0,123,__LINE__, 0xbfdc7d5d, 0xcdd2f44f, 0xbfdd70a3, 0xd70a3d64},	/* -0.445152=f(-0.46)*/
{63, 0,123,__LINE__, 0xbfdbe83c, 0xdec99730, 0xbfdccccc, 0xccccccc0},	/* -0.43605=f(-0.45)*/
{64, 0,123,__LINE__, 0xbfdb528c, 0xceec6b8c, 0xbfdc28f5, 0xc28f5c1c},	/* -0.426913=f(-0.44)*/
{63, 0,123,__LINE__, 0xbfdabc4f, 0x3b0df56c, 0xbfdb851e, 0xb851eb78},	/* -0.417743=f(-0.43)*/
{64, 0,123,__LINE__, 0xbfda2585, 0xd3eeb962, 0xbfdae147, 0xae147ad4},	/* -0.40854=f(-0.42)*/
{64, 0,123,__LINE__, 0xbfd98e32, 0x5e6c9df0, 0xbfda3d70, 0xa3d70a30},	/* -0.399304=f(-0.41)*/
{64, 0,123,__LINE__, 0xbfd8f656, 0xb3acceca, 0xbfd99999, 0x9999998c},	/* -0.390035=f(-0.4)*/
{64, 0,123,__LINE__, 0xbfd85df4, 0xc13fd1f5, 0xbfd8f5c2, 0x8f5c28e8},	/* -0.380735=f(-0.39)*/
{64, 0,123,__LINE__, 0xbfd7c50e, 0x893f7fd0, 0xbfd851eb, 0x851eb844},	/* -0.371402=f(-0.38)*/
{63, 0,123,__LINE__, 0xbfd72ba6, 0x22669020, 0xbfd7ae14, 0x7ae147a0},	/* -0.362039=f(-0.37)*/
{64, 0,123,__LINE__, 0xbfd691bd, 0xb8217006, 0xbfd70a3d, 0x70a3d6fc},	/* -0.352645=f(-0.36)*/
{64, 0,123,__LINE__, 0xbfd5f757, 0x8a9816c0, 0xbfd66666, 0x66666658},	/* -0.343222=f(-0.35)*/
{64, 0,123,__LINE__, 0xbfd55c75, 0xeeb091a1, 0xbfd5c28f, 0x5c28f5b4},	/* -0.333768=f(-0.34)*/
{64, 0,123,__LINE__, 0xbfd4c11b, 0x4e0a028a, 0xbfd51eb8, 0x51eb8510},	/* -0.324286=f(-0.33)*/
{64, 0,123,__LINE__, 0xbfd4254a, 0x26efcfab, 0xbfd47ae1, 0x47ae146c},	/* -0.314776=f(-0.32)*/
{64, 0,123,__LINE__, 0xbfd38905, 0x0c44c709, 0xbfd3d70a, 0x3d70a3c8},	/* -0.305238=f(-0.31)*/
{63, 0,123,__LINE__, 0xbfd2ec4e, 0xa565fcb2, 0xbfd33333, 0x33333324},	/* -0.295673=f(-0.3)*/
{64, 0,123,__LINE__, 0xbfd24f29, 0xae052f2f, 0xbfd28f5c, 0x28f5c280},	/* -0.286082=f(-0.29)*/
{64, 0,123,__LINE__, 0xbfd1b198, 0xf5fa8300, 0xbfd1eb85, 0x1eb851dc},	/* -0.276465=f(-0.28)*/
{63, 0,123,__LINE__, 0xbfd1139f, 0x610d6b9f, 0xbfd147ae, 0x147ae138},	/* -0.266823=f(-0.27)*/
{63, 0,123,__LINE__, 0xbfd0753f, 0xe6b49e7d, 0xbfd0a3d7, 0x0a3d7094},	/* -0.257156=f(-0.26)*/
{64, 0,123,__LINE__, 0xbfcfacfb, 0x2399e618, 0xbfcfffff, 0xffffffe0},	/* -0.247466=f(-0.25)*/
{63, 0,123,__LINE__, 0xbfce6eb7, 0x008e3358, 0xbfceb851, 0xeb851e98},	/* -0.237754=f(-0.24)*/
{64, 0,123,__LINE__, 0xbfcd2fb9, 0xc5983561, 0xbfcd70a3, 0xd70a3d50},	/* -0.228019=f(-0.23)*/
{64, 0,123,__LINE__, 0xbfcbf009, 0xf8b12c56, 0xbfcc28f5, 0xc28f5c08},	/* -0.218263=f(-0.22)*/
{64, 0,123,__LINE__, 0xbfcaafae, 0x439d8a6b, 0xbfcae147, 0xae147ac0},	/* -0.208486=f(-0.21)*/
{64, 0,123,__LINE__, 0xbfc96ead, 0x72fe8b12, 0xbfc99999, 0x99999978},	/* -0.19869=f(-0.2)*/
{64, 0,123,__LINE__, 0xbfc82d0e, 0x7551814f, 0xbfc851eb, 0x851eb830},	/* -0.188875=f(-0.19)*/
{64, 0,123,__LINE__, 0xbfc6ead8, 0x59dd1101, 0xbfc70a3d, 0x70a3d6e8},	/* -0.179042=f(-0.18)*/
{64, 0,123,__LINE__, 0xbfc5a812, 0x4f8c9853, 0xbfc5c28f, 0x5c28f5a0},	/* -0.169192=f(-0.17)*/
{64, 0,123,__LINE__, 0xbfc464c3, 0xa3ba2071, 0xbfc47ae1, 0x47ae1458},	/* -0.159325=f(-0.16)*/
{64, 0,123,__LINE__, 0xbfc320f3, 0xc0e73e3a, 0xbfc33333, 0x33333310},	/* -0.149443=f(-0.15)*/
{64, 0,123,__LINE__, 0xbfc1dcaa, 0x2d655d91, 0xbfc1eb85, 0x1eb851c8},	/* -0.139547=f(-0.14)*/
{64, 0,123,__LINE__, 0xbfc097ee, 0x89ee0391, 0xbfc0a3d7, 0x0a3d7080},	/* -0.129637=f(-0.13)*/
{63, 0,123,__LINE__, 0xbfbea591, 0x20574a8b, 0xbfbeb851, 0xeb851e71},	/* -0.119714=f(-0.12)*/
{63, 0,123,__LINE__, 0xbfbc1a80, 0x22678344, 0xbfbc28f5, 0xc28f5be2},	/* -0.109779=f(-0.11)*/
{64, 0,123,__LINE__, 0xbfb98eb9, 0xe7e5fbf8, 0xbfb99999, 0x99999953},	/* -0.0998341=f(-0.1)*/
{64, 0,123,__LINE__, 0xbfb7024e, 0x67182895, 0xbfb70a3d, 0x70a3d6c4},	/* -0.0898789=f(-0.09)*/
{64, 0,123,__LINE__, 0xbfb4754d, 0xbb54e357, 0xbfb47ae1, 0x47ae1435},	/* -0.0799149=f(-0.08)*/
{64, 0,123,__LINE__, 0xbfb1e7c8, 0x2192e439, 0xbfb1eb85, 0x1eb851a6},	/* -0.069943=f(-0.07)*/
{63, 0,123,__LINE__, 0xbfaeb39b, 0xe9c4cf8b, 0xbfaeb851, 0xeb851e2d},	/* -0.0599641=f(-0.06)*/
{64, 0,123,__LINE__, 0xbfa996df, 0x55a82630, 0xbfa99999, 0x9999990e},	/* -0.0499792=f(-0.05)*/
{64, 0,123,__LINE__, 0xbfa4797b, 0x9f9e7351, 0xbfa47ae1, 0x47ae13ef},	/* -0.0399893=f(-0.04)*/
{64, 0,123,__LINE__, 0xbf9eb724, 0x0d66f6d4, 0xbf9eb851, 0xeb851da0},	/* -0.0299955=f(-0.03)*/
{64, 0,123,__LINE__, 0xbf947a87, 0xd14f5740, 0xbf947ae1, 0x47ae1362},	/* -0.0199987=f(-0.02)*/
{64, 0,123,__LINE__, 0xbf847aca, 0xe95088d5, 0xbf847ae1, 0x47ae1249},	/* -0.00999983=f(-0.01)*/
{64, 0,123,__LINE__, 0x3cd19000, 0x00000000, 0x3cd19000, 0x00000000},	/* 9.74915e-16=f(9.74915e-16)*/
{64, 0,123,__LINE__, 0x3f847aca, 0xe9508d39, 0x3f847ae1, 0x47ae16ad},	/* 0.00999983=f(0.01)*/
{64, 0,123,__LINE__, 0x3f947a87, 0xd14f5972, 0x3f947ae1, 0x47ae1594},	/* 0.0199987=f(0.02)*/
{63, 0,123,__LINE__, 0x3f9eb724, 0x0d66f905, 0x3f9eb851, 0xeb851fd2},	/* 0.0299955=f(0.03)*/
{64, 0,123,__LINE__, 0x3fa4797b, 0x9f9e746a, 0x3fa47ae1, 0x47ae1508},	/* 0.0399893=f(0.04)*/
{64, 0,123,__LINE__, 0x3fa996df, 0x55a82748, 0x3fa99999, 0x99999a27},	/* 0.0499792=f(0.05)*/
{64, 0,123,__LINE__, 0x3faeb39b, 0xe9c4d0a3, 0x3faeb851, 0xeb851f46},	/* 0.0599641=f(0.06)*/
{64, 0,123,__LINE__, 0x3fb1e7c8, 0x2192e4c5, 0x3fb1eb85, 0x1eb85232},	/* 0.069943=f(0.07)*/
{64, 0,123,__LINE__, 0x3fb4754d, 0xbb54e3e3, 0x3fb47ae1, 0x47ae14c1},	/* 0.0799149=f(0.08)*/
{64, 0,123,__LINE__, 0x3fb7024e, 0x67182921, 0x3fb70a3d, 0x70a3d750},	/* 0.0898789=f(0.09)*/
{64, 0,123,__LINE__, 0x3fb98eb9, 0xe7e5fc83, 0x3fb99999, 0x999999df},	/* 0.0998341=f(0.1)*/
{63, 0,123,__LINE__, 0x3fbc1a80, 0x226783cf, 0x3fbc28f5, 0xc28f5c6e},	/* 0.109779=f(0.11)*/
{64, 0,123,__LINE__, 0x3fbea591, 0x20574b16, 0x3fbeb851, 0xeb851efd},	/* 0.119714=f(0.12)*/
{64, 0,123,__LINE__, 0x3fc097ee, 0x89ee03d6, 0x3fc0a3d7, 0x0a3d70c6},	/* 0.129637=f(0.13)*/
{63, 0,123,__LINE__, 0x3fc1dcaa, 0x2d655dd6, 0x3fc1eb85, 0x1eb8520e},	/* 0.139547=f(0.14)*/
{64, 0,123,__LINE__, 0x3fc320f3, 0xc0e73e7f, 0x3fc33333, 0x33333356},	/* 0.149443=f(0.15)*/
{63, 0,123,__LINE__, 0x3fc464c3, 0xa3ba20b6, 0x3fc47ae1, 0x47ae149e},	/* 0.159325=f(0.16)*/
{64, 0,123,__LINE__, 0x3fc5a812, 0x4f8c9898, 0x3fc5c28f, 0x5c28f5e6},	/* 0.169192=f(0.17)*/
{64, 0,123,__LINE__, 0x3fc6ead8, 0x59dd1146, 0x3fc70a3d, 0x70a3d72e},	/* 0.179042=f(0.18)*/
{64, 0,123,__LINE__, 0x3fc82d0e, 0x75518194, 0x3fc851eb, 0x851eb876},	/* 0.188875=f(0.19)*/
{64, 0,123,__LINE__, 0x3fc96ead, 0x72fe8b56, 0x3fc99999, 0x999999be},	/* 0.19869=f(0.2)*/
{64, 0,123,__LINE__, 0x3fcaafae, 0x439d8ab0, 0x3fcae147, 0xae147b06},	/* 0.208486=f(0.21)*/
{64, 0,123,__LINE__, 0x3fcbf009, 0xf8b12c9a, 0x3fcc28f5, 0xc28f5c4e},	/* 0.218263=f(0.22)*/
{63, 0,123,__LINE__, 0x3fcd2fb9, 0xc59835a5, 0x3fcd70a3, 0xd70a3d96},	/* 0.228019=f(0.23)*/
{63, 0,123,__LINE__, 0x3fce6eb7, 0x008e339c, 0x3fceb851, 0xeb851ede},	/* 0.237754=f(0.24)*/
{63, 0,123,__LINE__, 0x3fcfacfb, 0x2399e65c, 0x3fd00000, 0x00000013},	/* 0.247466=f(0.25)*/
{64, 0,123,__LINE__, 0x3fd0753f, 0xe6b49e9f, 0x3fd0a3d7, 0x0a3d70b7},	/* 0.257156=f(0.26)*/
{64, 0,123,__LINE__, 0x3fd1139f, 0x610d6bc1, 0x3fd147ae, 0x147ae15b},	/* 0.266823=f(0.27)*/
{64, 0,123,__LINE__, 0x3fd1b198, 0xf5fa8322, 0x3fd1eb85, 0x1eb851ff},	/* 0.276465=f(0.28)*/
{63, 0,123,__LINE__, 0x3fd24f29, 0xae052f51, 0x3fd28f5c, 0x28f5c2a3},	/* 0.286082=f(0.29)*/
{64, 0,123,__LINE__, 0x3fd2ec4e, 0xa565fcd4, 0x3fd33333, 0x33333347},	/* 0.295673=f(0.3)*/
{63, 0,123,__LINE__, 0x3fd38905, 0x0c44c72b, 0x3fd3d70a, 0x3d70a3eb},	/* 0.305238=f(0.31)*/
{64, 0,123,__LINE__, 0x3fd4254a, 0x26efcfcc, 0x3fd47ae1, 0x47ae148f},	/* 0.314776=f(0.32)*/
{64, 0,123,__LINE__, 0x3fd4c11b, 0x4e0a02ab, 0x3fd51eb8, 0x51eb8533},	/* 0.324286=f(0.33)*/
{64, 0,123,__LINE__, 0x3fd55c75, 0xeeb091c2, 0x3fd5c28f, 0x5c28f5d7},	/* 0.333768=f(0.34)*/
{64, 0,123,__LINE__, 0x3fd5f757, 0x8a9816e1, 0x3fd66666, 0x6666667b},	/* 0.343222=f(0.35)*/
{63, 0,123,__LINE__, 0x3fd691bd, 0xb8217027, 0x3fd70a3d, 0x70a3d71f},	/* 0.352645=f(0.36)*/
{63, 0,123,__LINE__, 0x3fd72ba6, 0x22669041, 0x3fd7ae14, 0x7ae147c3},	/* 0.362039=f(0.37)*/
{64, 0,123,__LINE__, 0x3fd7c50e, 0x893f7ff1, 0x3fd851eb, 0x851eb867},	/* 0.371402=f(0.38)*/
{63, 0,123,__LINE__, 0x3fd85df4, 0xc13fd216, 0x3fd8f5c2, 0x8f5c290b},	/* 0.380735=f(0.39)*/
{64, 0,123,__LINE__, 0x3fd8f656, 0xb3acceea, 0x3fd99999, 0x999999af},	/* 0.390035=f(0.4)*/
{64, 0,123,__LINE__, 0x3fd98e32, 0x5e6c9e11, 0x3fda3d70, 0xa3d70a53},	/* 0.399304=f(0.41)*/
{64, 0,123,__LINE__, 0x3fda2585, 0xd3eeb982, 0x3fdae147, 0xae147af7},	/* 0.40854=f(0.42)*/
{64, 0,123,__LINE__, 0x3fdabc4f, 0x3b0df58c, 0x3fdb851e, 0xb851eb9b},	/* 0.417743=f(0.43)*/
{64, 0,123,__LINE__, 0x3fdb528c, 0xceec6bac, 0x3fdc28f5, 0xc28f5c3f},	/* 0.426913=f(0.44)*/
{64, 0,123,__LINE__, 0x3fdbe83c, 0xdec9974f, 0x3fdccccc, 0xcccccce3},	/* 0.43605=f(0.45)*/
{64, 0,123,__LINE__, 0x3fdc7d5d, 0xcdd2f46f, 0x3fdd70a3, 0xd70a3d87},	/* 0.445152=f(0.46)*/
{64, 0,123,__LINE__, 0x3fdd11ee, 0x12ef7057, 0x3fde147a, 0xe147ae2b},	/* 0.454219=f(0.47)*/
{63, 0,123,__LINE__, 0x3fdda5ec, 0x3885fd37, 0x3fdeb851, 0xeb851ecf},	/* 0.463252=f(0.48)*/
{64, 0,123,__LINE__, 0x3fde3956, 0xdc3f98d0, 0x3fdf5c28, 0xf5c28f73},	/* 0.47225=f(0.49)*/
{63, 0,123,__LINE__, 0x3fdecc2c, 0xaec5161d, 0x3fe00000, 0x0000000b},	/* 0.481212=f(0.5)*/
{63, 0,123,__LINE__, 0x3fdf5e6c, 0x7378f90b, 0x3fe051eb, 0x851eb85d},	/* 0.490138=f(0.51)*/
{64, 0,123,__LINE__, 0x3fdff015, 0x002db24d, 0x3fe0a3d7, 0x0a3d70af},	/* 0.499028=f(0.52)*/
{64, 0,123,__LINE__, 0x3fe04092, 0x9e6c440a, 0x3fe0f5c2, 0x8f5c2901},	/* 0.507882=f(0.53)*/
{64, 0,123,__LINE__, 0x3fe088ce, 0x11a0bb78, 0x3fe147ae, 0x147ae153},	/* 0.5167=f(0.54)*/
{63, 0,123,__LINE__, 0x3fe0d0bc, 0x5f582a2f, 0x3fe19999, 0x999999a5},	/* 0.52548=f(0.55)*/
{64, 0,123,__LINE__, 0x3fe1185d, 0x15cbbd66, 0x3fe1eb85, 0x1eb851f7},	/* 0.534224=f(0.56)*/
{63, 0,123,__LINE__, 0x3fe15faf, 0xcb9e2252, 0x3fe23d70, 0xa3d70a49},	/* 0.542931=f(0.57)*/
{64, 0,123,__LINE__, 0x3fe1a6b4, 0x1faeccfc, 0x3fe28f5c, 0x28f5c29b},	/* 0.5516=f(0.58)*/
{64, 0,123,__LINE__, 0x3fe1ed69, 0xb8ec6901, 0x3fe2e147, 0xae147aed},	/* 0.560231=f(0.59)*/
{64, 0,123,__LINE__, 0x3fe233d0, 0x4626939e, 0x3fe33333, 0x3333333f},	/* 0.568825=f(0.6)*/
{64, 0,123,__LINE__, 0x3fe279e7, 0x7ddefd54, 0x3fe3851e, 0xb851eb91},	/* 0.577381=f(0.61)*/
{64, 0,123,__LINE__, 0x3fe2bfaf, 0x1e1a0ffb, 0x3fe3d70a, 0x3d70a3e3},	/* 0.585899=f(0.62)*/
{64, 0,123,__LINE__, 0x3fe30526, 0xec2f3503, 0x3fe428f5, 0xc28f5c35},	/* 0.594379=f(0.63)*/
{64, 0,123,__LINE__, 0x3fe34a4e, 0xb498d638, 0x3fe47ae1, 0x47ae1487},	/* 0.602821=f(0.64)*/
{64, 0,123,__LINE__, 0x3fe38f26, 0x4ac4321d, 0x3fe4cccc, 0xccccccd9},	/* 0.611224=f(0.65)*/
{64, 0,123,__LINE__, 0x3fe3d3ad, 0x88e11ba1, 0x3fe51eb8, 0x51eb852b},	/* 0.61959=f(0.66)*/
{64, 0,123,__LINE__, 0x3fe417e4, 0x4fb1bba2, 0x3fe570a3, 0xd70a3d7d},	/* 0.627916=f(0.67)*/
{64, 0,123,__LINE__, 0x3fe45bca, 0x865a6973, 0x3fe5c28f, 0x5c28f5cf},	/* 0.636205=f(0.68)*/
{64, 0,123,__LINE__, 0x3fe49f60, 0x1a31ae3d, 0x3fe6147a, 0xe147ae21},	/* 0.644455=f(0.69)*/
{64, 0,123,__LINE__, 0x3fe4e2a4, 0xfe9085e8, 0x3fe66666, 0x66666673},	/* 0.652667=f(0.7)*/
{64, 0,123,__LINE__, 0x3fe52599, 0x2ca2eeee, 0x3fe6b851, 0xeb851ec5},	/* 0.66084=f(0.71)*/
{64, 0,123,__LINE__, 0x3fe5683c, 0xa338d94b, 0x3fe70a3d, 0x70a3d717},	/* 0.668974=f(0.72)*/
{64, 0,123,__LINE__, 0x3fe5aa8f, 0x6697838f, 0x3fe75c28, 0xf5c28f69},	/* 0.67707=f(0.73)*/
{64, 0,123,__LINE__, 0x3fe5ec91, 0x804b53e9, 0x3fe7ae14, 0x7ae147bb},	/* 0.685128=f(0.74)*/
{63, 0,123,__LINE__, 0x3fe62e42, 0xfefa39fa, 0x3fe80000, 0x0000000d},	/* 0.693147=f(0.75)*/
{64, 0,123,__LINE__, 0x3fe66fa3, 0xf636a508, 0x3fe851eb, 0x851eb85f},	/* 0.701128=f(0.76)*/
{63, 0,123,__LINE__, 0x3fe6b0b4, 0x7e531950, 0x3fe8a3d7, 0x0a3d70b1},	/* 0.70907=f(0.77)*/
{64, 0,123,__LINE__, 0x3fe6f174, 0xb4366dff, 0x3fe8f5c2, 0x8f5c2903},	/* 0.716975=f(0.78)*/
{64, 0,123,__LINE__, 0x3fe731e4, 0xb930bc95, 0x3fe947ae, 0x147ae155},	/* 0.724841=f(0.79)*/
{64, 0,123,__LINE__, 0x3fe77204, 0xb2d1096a, 0x3fe99999, 0x999999a7},	/* 0.732668=f(0.8)*/
{64, 0,123,__LINE__, 0x3fe7b1d4, 0xcabbac37, 0x3fe9eb85, 0x1eb851f9},	/* 0.740458=f(0.81)*/
{63, 0,123,__LINE__, 0x3fe7f155, 0x2e817eb9, 0x3fea3d70, 0xa3d70a4b},	/* 0.74821=f(0.82)*/
{64, 0,123,__LINE__, 0x3fe83086, 0x0f77d6a0, 0x3fea8f5c, 0x28f5c29d},	/* 0.755923=f(0.83)*/
{64, 0,123,__LINE__, 0x3fe86f67, 0xa2914f53, 0x3feae147, 0xae147aef},	/* 0.763599=f(0.84)*/
{64, 0,123,__LINE__, 0x3fe8adfa, 0x2037674b, 0x3feb3333, 0x33333341},	/* 0.771237=f(0.85)*/
{63, 0,123,__LINE__, 0x3fe8ec3d, 0xc424f429, 0x3feb851e, 0xb851eb93},	/* 0.778838=f(0.86)*/
{63, 0,123,__LINE__, 0x3fe92a32, 0xcd416ff4, 0x3febd70a, 0x3d70a3e5},	/* 0.786401=f(0.87)*/
{64, 0,123,__LINE__, 0x3fe967d9, 0x7d7d2167, 0x3fec28f5, 0xc28f5c37},	/* 0.793927=f(0.88)*/
{64, 0,123,__LINE__, 0x3fe9a532, 0x19ae209b, 0x3fec7ae1, 0x47ae1489},	/* 0.801415=f(0.89)*/
{64, 0,123,__LINE__, 0x3fe9e23c, 0xe96e38df, 0x3feccccc, 0xccccccdb},	/* 0.808867=f(0.9)*/
{64, 0,123,__LINE__, 0x3fea1efa, 0x36f9a800, 0x3fed1eb8, 0x51eb852d},	/* 0.816281=f(0.91)*/
{64, 0,123,__LINE__, 0x3fea5b6a, 0x4f0ebae6, 0x3fed70a3, 0xd70a3d7f},	/* 0.823659=f(0.92)*/
{64, 0,123,__LINE__, 0x3fea978d, 0x80ce46e8, 0x3fedc28f, 0x5c28f5d1},	/* 0.831=f(0.93)*/
{63, 0,123,__LINE__, 0x3fead364, 0x1d9cfeef, 0x3fee147a, 0xe147ae23},	/* 0.838305=f(0.94)*/
{64, 0,123,__LINE__, 0x3feb0eee, 0x7905a306, 0x3fee6666, 0x66666675},	/* 0.845573=f(0.95)*/
{64, 0,123,__LINE__, 0x3feb4a2c, 0xe89c08bf, 0x3feeb851, 0xeb851ec7},	/* 0.852805=f(0.96)*/
{63, 0,123,__LINE__, 0x3feb851f, 0xc3e0fa74, 0x3fef0a3d, 0x70a3d719},	/* 0.86=f(0.97)*/
{64, 0,123,__LINE__, 0x3febbfc7, 0x6426eb20, 0x3fef5c28, 0xf5c28f6b},	/* 0.867161=f(0.98)*/
{64, 0,123,__LINE__, 0x3febfa24, 0x24777c6e, 0x3fefae14, 0x7ae147bd},	/* 0.874285=f(0.99)*/
{63, 0,123,__LINE__, 0x3fec3436, 0x6179d431, 0x3ff00000, 0x00000007},	/* 0.881374=f(1)*/
{64, 0,123,__LINE__, 0x3fec6dfe, 0x7959be70, 0x3ff028f5, 0xc28f5c30},	/* 0.888427=f(1.01)*/
{64, 0,123,__LINE__, 0x3feca77c, 0xcbaf98e2, 0x3ff051eb, 0x851eb859},	/* 0.895445=f(1.02)*/
{64, 0,123,__LINE__, 0x3fece0b1, 0xb96904aa, 0x3ff07ae1, 0x47ae1482},	/* 0.902428=f(1.03)*/
{64, 0,123,__LINE__, 0x3fed199d, 0xa4b25ae3, 0x3ff0a3d7, 0x0a3d70ab},	/* 0.909377=f(1.04)*/
{63, 0,123,__LINE__, 0x3fed5240, 0xf0e0e082, 0x3ff0cccc, 0xccccccd4},	/* 0.916291=f(1.05)*/
{64, 0,123,__LINE__, 0x3fed8a9c, 0x025db5e9, 0x3ff0f5c2, 0x8f5c28fd},	/* 0.92317=f(1.06)*/
{64, 0,123,__LINE__, 0x3fedc2af, 0x3e917e85, 0x3ff11eb8, 0x51eb8526},	/* 0.930015=f(1.07)*/
{64, 0,123,__LINE__, 0x3fedfa7b, 0x0bd0bc95, 0x3ff147ae, 0x147ae14f},	/* 0.936826=f(1.08)*/
{64, 0,123,__LINE__, 0x3fee31ff, 0xd148dd64, 0x3ff170a3, 0xd70a3d78},	/* 0.943603=f(1.09)*/
{64, 0,123,__LINE__, 0x3fee693d, 0xf6edf1f0, 0x3ff19999, 0x999999a1},	/* 0.950347=f(1.1)*/
{64, 0,123,__LINE__, 0x3feea035, 0xe5691030, 0x3ff1c28f, 0x5c28f5ca},	/* 0.957057=f(1.11)*/
{64, 0,123,__LINE__, 0x3feed6e8, 0x060758ed, 0x3ff1eb85, 0x1eb851f3},	/* 0.963734=f(1.12)*/
{64, 0,123,__LINE__, 0x3fef0d54, 0xc2a99e45, 0x3ff2147a, 0xe147ae1c},	/* 0.970377=f(1.13)*/
{64, 0,123,__LINE__, 0x3fef437c, 0x85b4a6dc, 0x3ff23d70, 0xa3d70a45},	/* 0.976988=f(1.14)*/
{64, 0,123,__LINE__, 0x3fef795f, 0xba0209c4, 0x3ff26666, 0x6666666e},	/* 0.983566=f(1.15)*/
{64, 0,123,__LINE__, 0x3fefaefe, 0xcad19f20, 0x3ff28f5c, 0x28f5c297},	/* 0.990112=f(1.16)*/
{64, 0,123,__LINE__, 0x3fefe45a, 0x23bb81a4, 0x3ff2b851, 0xeb851ec0},	/* 0.996625=f(1.17)*/
{64, 0,123,__LINE__, 0x3ff00cb9, 0x18514e7c, 0x3ff2e147, 0xae147ae9},	/* 1.00311=f(1.18)*/
{64, 0,123,__LINE__, 0x3ff02723, 0xaed3e291, 0x3ff30a3d, 0x70a3d712},	/* 1.00956=f(1.19)*/
{64, 0,123,__LINE__, 0xc0044c62, 0xa1e4f804, 0xc01921fb, 0x54442d18},	/* -2.5373=f(-6.28319)*/
{64, 0,123,__LINE__, 0xc002090a, 0x84a43b1b, 0xc012d97c, 0x7f3321d2},	/* -2.25441=f(-4.71239)*/
{64, 0,123,__LINE__, 0xbffdcbf6, 0x9f10006d, 0xc00921fb, 0x54442d18},	/* -1.8623=f(-3.14159)*/
{64, 0,123,__LINE__, 0xbff3bc04, 0xe847ec05, 0xbff921fb, 0x54442d18},	/* -1.2334=f(-1.5708)*/
{64, 0,123,__LINE__, 0x00000000, 0x00000000, 0x00000000, 0x00000000},	/* 0=f(0)*/
{64, 0,123,__LINE__, 0x3ff3bc04, 0xe847ec05, 0x3ff921fb, 0x54442d18},	/* 1.2334=f(1.5708)*/
{64, 0,123,__LINE__, 0x3ffdcbf6, 0x9f10006d, 0x400921fb, 0x54442d18},	/* 1.8623=f(3.14159)*/
{64, 0,123,__LINE__, 0x4002090a, 0x84a43b1b, 0x4012d97c, 0x7f3321d2},	/* 2.25441=f(4.71239)*/
{64, 0,123,__LINE__, 0xc01060e4, 0xa5fbe5ca, 0xc03e0000, 0x00000000},	/* -4.09462=f(-30)*/
{64, 0,123,__LINE__, 0xc0102531, 0x54812870, 0xc03c4ccc, 0xcccccccd},	/* -4.03632=f(-28.3)*/
{63, 0,123,__LINE__, 0xc00fcb98, 0x4685405e, 0xc03a9999, 0x9999999a},	/* -3.97441=f(-26.6)*/
{64, 0,123,__LINE__, 0xc00f4470, 0xa29f290c, 0xc038e666, 0x66666667},	/* -3.90842=f(-24.9)*/
{64, 0,123,__LINE__, 0xc00eb3bd, 0x68b50b69, 0xc0373333, 0x33333334},	/* -3.83776=f(-23.2)*/
{64, 0,123,__LINE__, 0xc00e180b, 0x68a00467, 0xc0358000, 0x00000001},	/* -3.76174=f(-21.5)*/
{64, 0,123,__LINE__, 0xc00d6f8b, 0xf981cc3a, 0xc033cccc, 0xccccccce},	/* -3.67947=f(-19.8)*/
{64, 0,123,__LINE__, 0xc00cb7f4, 0x416d82e3, 0xc0321999, 0x9999999b},	/* -3.58982=f(-18.1)*/
{64, 0,123,__LINE__, 0xc00bee4c, 0x6fb6e99b, 0xc0306666, 0x66666668},	/* -3.49136=f(-16.4)*/
{64, 0,123,__LINE__, 0xc00b0ea4, 0x72aedff4, 0xc02d6666, 0x6666666a},	/* -3.38215=f(-14.7)*/
{64, 0,123,__LINE__, 0xc00a139a, 0xc6c0b4fc, 0xc02a0000, 0x00000004},	/* -3.25957=f(-13)*/
{64, 0,123,__LINE__, 0xc008f58f, 0x34777dd3, 0xc0269999, 0x9999999e},	/* -3.1199=f(-11.3)*/
{63, 0,123,__LINE__, 0xc007a930, 0x785ee481, 0xc0233333, 0x33333338},	/* -2.95761=f(-9.6)*/
{64, 0,123,__LINE__, 0xc0061ca7, 0xc27714a7, 0xc01f9999, 0x999999a3},	/* -2.76399=f(-7.9)*/
{64, 0,123,__LINE__, 0xc004316f, 0x09d4ec2c, 0xc018cccc, 0xccccccd6},	/* -2.52414=f(-6.2)*/
{64, 0,123,__LINE__, 0xc001acbe, 0x7dcff697, 0xc0120000, 0x00000009},	/* -2.20935=f(-4.5)*/
{64, 0,123,__LINE__, 0xbffc0d39, 0xbf8abae7, 0xc0066666, 0x66666678},	/* -1.75323=f(-2.8)*/
{64, 0,123,__LINE__, 0xbfee693d, 0xf6edf216, 0xbff19999, 0x999999bd},	/* -0.950347=f(-1.1)*/
{64, 0,123,__LINE__, 0x3fe233d0, 0x46269357, 0x3fe33333, 0x333332ec},	/* 0.568825=f(0.6)*/
{64, 0,123,__LINE__, 0x3ff91fdc, 0x64de0e42, 0x40026666, 0x66666654},	/* 1.57028=f(2.3)*/
{64, 0,123,__LINE__, 0x4000c1f8, 0xa6e80ee7, 0x400fffff, 0xffffffee},	/* 2.09471=f(4)*/
{64, 0,123,__LINE__, 0x4003879e, 0xb8dfd8bc, 0x4016cccc, 0xccccccc4},	/* 2.44122=f(5.7)*/
{64, 0,123,__LINE__, 0x400597e2, 0x0a50c554, 0x401d9999, 0x99999991},	/* 2.69916=f(7.4)*/
{64, 0,123,__LINE__, 0x40073c44, 0x35744319, 0x40223333, 0x3333332f},	/* 2.90443=f(9.1)*/
{64, 0,123,__LINE__, 0x40089940, 0x5e357d29, 0x40259999, 0x99999995},	/* 3.07483=f(10.8)*/
{64, 0,123,__LINE__, 0x4009c386, 0xd2b8b56c, 0x4028ffff, 0xfffffffb},	/* 3.22047=f(12.5)*/
{64, 0,123,__LINE__, 0x400ac7f0, 0x7f0f1e89, 0x402c6666, 0x66666661},	/* 3.34763=f(14.2)*/
{64, 0,123,__LINE__, 0x400baf02, 0x5af3c784, 0x402fcccc, 0xccccccc7},	/* 3.46045=f(15.9)*/
{64, 0,123,__LINE__, 0x400c7eac, 0x5b92cf44, 0x40319999, 0x99999997},	/* 3.56185=f(17.6)*/
{64, 0,123,__LINE__, 0x400d3b3b, 0xdb3c5660, 0x40334ccc, 0xccccccca},	/* 3.65392=f(19.3)*/
{64, 0,123,__LINE__, 0x400de7e8, 0x4ab59e16, 0x4034ffff, 0xfffffffd},	/* 3.73824=f(21)*/
{64, 0,123,__LINE__, 0x400e8729, 0x64206f74, 0x4036b333, 0x33333330},	/* 3.816=f(22.7)*/
{64, 0,123,__LINE__, 0x400f1aee, 0x5e1b0559, 0x40386666, 0x66666663},	/* 3.88815=f(24.4)*/
{64, 0,123,__LINE__, 0x400fa4c2, 0x9886fc48, 0x403a1999, 0x99999996},	/* 3.95545=f(26.1)*/
{64, 0,123,__LINE__, 0x401012f3, 0x5ffa8bd3, 0x403bcccc, 0xccccccc9},	/* 4.01851=f(27.8)*/
{63, 0,123,__LINE__, 0x40104fb1, 0x4017a7ca, 0x403d7fff, 0xfffffffc},	/* 4.07782=f(29.5)*/
{0}
};
void test_asinh(m)   {run_vector_1(m,asinh_vec,(char *)(asinh),"asinh","dd");   }	
